@@ -1,16 +1,32 @@
 #!/bin/sh
 
+# mk1pass, Generate random strings for passwords.
+# Copyright (C) 2023-2024 Mike Turkey
+# contact: voice[ATmark]miketurkey.com
+# license: GPLv3 License
+
 T=$(dirname "$0")
 SCRDIR=$(cd "$T"; pwd)
 CONF="$SCRDIR"/snakeland-mk1pass.conf
-INSTALLSNAKE="$SCRDIR"/tools/install-snakeland.sh
+INSTALLSNAKE="$SCRDIR"/snakeland/install.sh
 
 ### Function ###
 check_rootuser(){
     local ARGSUSER TMP_USER
     ARGSUSER='root'
-    TMP_USER=$(id -p | grep uid | awk '{print $2}')
-    if test "$ARGSUSER" != "$TMP_USER"; then
+    case "$(uname -s)" in
+	'Darwin' | 'FreeBSD')
+	    TMP_USER=$(id -p | grep uid | awk '{print $2}')
+	    ;;
+	'Linux')
+	    TMP_USER=$(id -u -n)
+	    ;;
+	*)
+	    TMP_USER=$(id -p | grep uid | awk '{print $2}')
+	    ;;
+    esac
+	    
+    if [ "$ARGSUSER" != "$TMP_USER" ]; then
         echo 'Error: Not root user.' " [uid: $TMP_USER]"
         exit 1
     fi
@@ -30,4 +46,4 @@ if ! snakeland --version > /dev/null 2>&1; then
 fi
 
 snakeland install "$CONF"  || exit 1
-
+exit 0
